==> haskell-asn1-parse-0.9.5-329.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-Hme4OEszotC4nSFnPS5Zk5
key:                  asn1-parse-0.9.5-Hme4OEszotC4nSFnPS5Zk5
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  47c96395cf25702ca93516f8efb27874
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-parse
hs-libraries:         HSasn1-parse-0.9.5-Hme4OEszotC4nSFnPS5Zk5
depends:
    asn1-encoding-0.9.6-f2brNU34Hf3xe9CSPQRHn
    asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO base-4.18.2.1
    bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.5-330-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-DinlHyBahm8CwVodLrJ7aO
key:                  asn1-parse-0.9.5-DinlHyBahm8CwVodLrJ7aO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  e42f2daf2242277b37cef639283474ac
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-parse
hs-libraries:         HSasn1-parse-0.9.5-DinlHyBahm8CwVodLrJ7aO
depends:
    asn1-encoding-0.9.6-4rkJHO0pUeFCGFdsLyrUdt
    asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e base-4.18.2.1
    bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
